@@ -1,18 +1,18 @@
-#  Copyright (C) 2020 Dremio
+# Copyright (C) 2020 Dremio
 #
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 #
-#  http://www.apache.org/licenses/LICENSE-2.0
+# http://www.apache.org/licenses/LICENSE-2.0
 #
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 """Tests for `content CLI command`."""
-from typing import List
+from typing import List, Optional
 
 import pytest
 import simplejson
@@ -265,7 +265,10 @@ def _create_iceberg_table(
 
 
 def _create_delta_lake_table(
-    table_id: str, metadata_location_history: List[str] = None, checkpoint_location_history: List[str] = None, last_checkpoint: str = "x"
+    table_id: str,
+    metadata_location_history: Optional[List[str]] = None,
+    checkpoint_location_history: Optional[List[str]] = None,
+    last_checkpoint: str = "x",
 ) -> DeltaLakeTable:
     if checkpoint_location_history is None:
         checkpoint_location_history = ["def"]
