@@ -1,6 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-#
 # Copyright (C) 2020 Dremio
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -43,9 +40,11 @@ def test_client_interface_e2e() -> None:
     assert next(i for i in references if i.name == "test") == Branch("test", main_commit)
     reference = client.get_reference("test")
     assert created_reference == reference
+    assert isinstance(reference.hash_, str)
     tables = client.list_keys(reference.name, reference.hash_)
     assert isinstance(tables, Entries)
     assert len(tables.entries) == 0
+    assert isinstance(main_commit, str)
     client.delete_branch("test", main_commit)
     references = client.list_references().references
     assert len(references) == 1
